#ifndef INCLUDED_QESAVEFILEDIALOG_H
#define INCLUDED_QESAVEFILEDIALOG_H

#include <string>

#include <qdialog.h>
#include <qlayout.h>

#include "qefilenameinput.h"
#include "qeacceptinput.h"

class QVGroupBox;

/**
 * Dialog for selecting audio file, format and various 
 * related options.
 */
class QESaveFileDialog : public QDialog {
  Q_OBJECT
 public:

  QESaveFileDialog (QWidget *parent=0, const char *name=0);

 public:

  std::string result_filename(void) const { return(fname->result_filename()); }
  const std::string& current_dir(void) const { return(fname->current_dir()); }

 private:

  QEFilenameInput* fname; 
  QEAcceptInput* okcancel;
};

#endif
